==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/tests/lookup/dynamic/builtin/Farm.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.lookup.dynamic.builtin;

import javax.enterprise.inject.Instance;
import javax.enterprise.inject.Produces;
import javax.inject.Inject;

public class Farm {

    @Inject
    private Instance<Animal> animal;

    @Inject
    private Instance<AbstractAnimal> abstractAnimal;

    @Inject
    @FarmBased
    private Instance<Cow> cow;

    public Instance<Animal> getAnimal() {
        return animal;
    }

    public Instance<AbstractAnimal> getAbstractAnimal() {
        return abstractAnimal;
    }

    public Instance<Cow> getCow() {
        return cow;
    }

    @Produces
    public Sheep produceSheep() {
        return new Sheep();
    }

    @Produces
    public Sheep[] produceSheeps() {
        return new Sheep[] {};
    }

    @FarmBased
    @Produces
    public int produceSheepCount() {
        return 0;
    }

}

==> cdi-tck-3.0.3-dist.zip: org/jboss/cdi/tck/tests/lookup/dynamic/builtin/Farm.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.lookup.dynamic.builtin;

import jakarta.enterprise.inject.Instance;
import jakarta.enterprise.inject.Produces;
import jakarta.inject.Inject;

public class Farm {

    @Inject
    private Instance<Animal> animal;

    @Inject
    private Instance<AbstractAnimal> abstractAnimal;

    @Inject
    @FarmBased
    private Instance<Cow> cow;

    public Instance<Animal> getAnimal() {
        return animal;
    }

    public Instance<AbstractAnimal> getAbstractAnimal() {
        return abstractAnimal;
    }

    public Instance<Cow> getCow() {
        return cow;
    }

    @Produces
    public Sheep produceSheep() {
        return new Sheep();
    }

    @Produces
    public Sheep[] produceSheeps() {
        return new Sheep[] {};
    }

    @FarmBased
    @Produces
    public int produceSheepCount() {
        return 0;
    }

}
